#ifndef _kYSEC_Pblk_H
#define _kYSEC_Pblk_H

#include <limits.h>

#define XML_HASH_SIZE   64

struct kysec_pblk_kernel {
        char path[PATH_MAX];
        char hash[XML_HASH_SIZE + 1];
};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * 获取文件路径的hash值
 */
char *kysec_pblk_get_path_hash(const char *filepath);

/*
 * 程序黑名单添加接口
 * 参数：
 *      path：需要添加到程序黑名单列表的文件路径，该文件必须为可执行文件、shell脚本、python脚本、
 *            so动态链接库、ko内核模块；
 * 返回值：
 *      0： 添加成功
 *      -1：添加失败
 *      -2：参数错误，路径不存在或参数不对
 *      -3：文件类型不对，非可执行文件、shell脚本、python脚本、so动态链接库、ko内核模块
 */
int kysec_pblk_add(char *path);

/*
 * 程序黑名单删除接口
 * 参数：
 *      path：需要添加到程序黑名单列表的文件路径，该文件必须为可执行文件、shell脚本、python脚本、
 *            so动态链接库、ko内核模块；
 * 返回值：
 *      0： 添加成功
 *      -1：添加失败
 *      -2：参数错误，路径不存在或参数不对
 *      -3：文件类型不对，非可执行文件、shell脚本、python脚本、so动态链接库、ko内核模块
 */
int kysec_pblk_remove(char *path);

/**
 * 获取指定路径path在xml文件中的节点数据
 */
struct kysec_pblk_kernel *kysec_pblk_read_node_with_path(char *filepath);

/**
 * 获取xml文件中所有节点数据
 * 返回值: kysec_pblk_kernel指针数组，大小为@count
 */
struct kysec_pblk_kernel *kysec_pblk_read_all_data(int *count);

/**
 * 获取 pblk.conf 中 action 的值，调用后需释放 action
 */
int kysec_pblk_get_action(char **action);

#ifdef __cplusplus
}
#endif

#endif // _kYSEC_Pblk_H

